import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    property int myId;
    property int level: 0;
    property alias myText: commentText.text
    property string author: commentAuthor.text
    property string date: commentDate.text
    property alias avatarSource: authorImage.source
    property alias replyButtonEnabled: commentsReply.visible
    property bool isEmpty: false

    signal answerRequested(int selectedId, string selectedAuthor, string selectedText)

    height: state == "EmptyComment" ? emptyComment.height : filledComment.height

    anchors {
        left: parent.left
        right: parent.right
    }

    states: [
        State {
            name: "EmptyComment"
            when: isEmpty
            PropertyChanges {
                target: emptyComment;
                visible: newsDetailPage.commentsEnabled
            }
            PropertyChanges {
                target: filledComment
                visible: false
            }
        },
        State {
            name: "FilledComment"
            when: !isEmpty
            PropertyChanges {
                target: emptyComment;
                visible: false
            }
            PropertyChanges {
                target: filledComment
                visible: true
            }
        }
    ]

    Label {
        id: emptyComment

        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
            bottomMargin: settings.mediumMargin
        }

        font.pixelSize: settings.fontSizeL + settings.fontCorrection
        wrapMode: Text.WordWrap

        text: "Nessun commento è ancora stato inserito per questo articolo.\n" +
              "Sii il primo a lasciarne uno."
    }

    Item {
        id: filledComment

        height: theComment.height

        anchors {
            left: parent.left
            right: parent.right
        }

        Item {
            id: levelMarginElement
            width: (level > 6 ? 6 : level) * 15
            anchors.left: parent.left
            height: theComment.height
        }

        Rectangle {
            id: theComment
            anchors {
                left: levelMarginElement.right
                right: parent.right
                verticalCenter: parent.verticalCenter
            }

            height: commentText.height + commentInfos.height + 25
            color: "transparent"
            border.color: "grey"
            border.width: 2

            Item {
                id: commentInfos

                height: commentAuthor.height + commentDate.height + 10
                anchors {
                    top: parent.top
                    left: parent.left
                    right: parent.right
                    leftMargin: settings.smallMargin
                    rightMargin: settings.smallMargin
                }

                Image {
                    id: authorImage

                    anchors {
                        left: parent.left
                        top: parent.top
                        verticalCenter: parent.verticalCenter
                    }

                    sourceSize.width: commentAuthor.height + commentDate.height
                    sourceSize.height: commentAuthor.height + commentDate.height
                    height: sourceSize.height

                    fillMode: Image.PreserveAspectFit
                }

                Item {
                    anchors {
                        left: authorImage.right
                        right: commentsReply.left
                        verticalCenter: parent.verticalCenter
                        leftMargin: settings.smallMargin
                    }

                    height: childrenRect.height

                    Label {
                        id: commentAuthor
                        anchors {
                            top: parent.top
                            left: parent.left
                            right: parent.right
                        }
                        text: author
                        
                        font.weight: Font.Bold
                        elide: Text.ElideRight
                        font.pixelSize: settings.fontSizeS + settings.fontCorrection
                        horizontalAlignment: Text.AlignLeft
                        color: window.platformWhite ? settings.nokiotecaBlue : settings.nokiotecaYellow
                    }

                    Label {
                        id: commentDate
                        anchors {
                            top: commentAuthor.bottom
                            left: parent.left
                            right: parent.right
                        }
                        text: date

                        elide: Text.ElideRight
                        font.pixelSize: settings.fontSizeXS + settings.fontCorrection
                        horizontalAlignment: Text.AlignLeft
                        color: window.platformWhite? settings.nokiotecaBlue : settings.nokiotecaYellow
                    }
                }

                Button {
                    id: commentsReply
                    anchors {
                        right: parent.right
                        verticalCenter: parent.verticalCenter
                    }
                    
                    width: 140
                    height: 30 + settings.fontCorrection
                    text: "Rispondi"
                    font.pixelSize: settings.fontSizeXS + settings.fontCorrection

                    onClicked: {
                        var lastNewLine = myText.trim().indexOf("<br");
                        answerRequested(myId, author, myText.trim().substring(0, (lastNewLine < 0 ? 50 : Math.min(lastNewLine, 50))));
                    }
                }
            }

            Text {
                id: commentText

                anchors {
                    top: commentInfos.bottom
                    left: parent.left
                    right: parent.right
                    topMargin: settings.smallMargin
                    leftMargin: settings.smallMargin
                    rightMargin: settings.smallMargin
                }

                width: parent.width

                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignLeft
                color: window.platformWhite ? settings.darkColor : settings.lightColor
                verticalAlignment: Text.AlignVCenter
                font.pixelSize: settings.fontSizeM + settings.fontCorrection
                textFormat: Text.RichText

                onLinkActivated: {
                    /*if((link.indexOf("www.nokioteca.net/blog/") >= 0 || link.indexOf("www.windowsteca.net/") >= 0) && 
                            link.indexOf("#comment") < 0 && link.indexOf("forum") < 0 && link.length > 40) {*/
                    if(link.indexOf("ia:") === 0) {
                        if(busyIndicator)
                            busyIndicator.opacity = 1;
                        if(!pageStack.busy) {
                            var thelink = encodeURIComponent(link.substring(3, link.length));
                            var detailsPage =
                                    pageStack.push(Qt.resolvedUrl("SingleNewsPage.qml"),
                                                              { newsId: thelink,
                                                                commentsCount: 0,
                                                                isWindowsteca: (link.indexOf("windowsteca") >= 0)
                                                              });
                            detailsPage.fetchDetails(thelink);
                        }
                        return;
                    }

                    Qt.openUrlExternally(link);
                }
            }
        }
    }
}
