import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: aboutPage
    anchors.fill: parent
    
    Flickable {
        anchors.fill: parent
        anchors.margins: settings.smallMargin

        contentWidth: width
        contentHeight: Math.max(floatingInfo.height + privacyPolicy.height + separatorLine.height + infoRow.height + 120, aboutPage.height - 10);

        Item {
            id: infoText

            anchors {
                top: parent.top
                bottom: privacyPolicy.top
                left: parent.left
                right: parent.right
            }

            Item {
                id: floatingInfo
                anchors {
                    left: parent.left
                    right: parent.right
                    verticalCenter: parent.verticalCenter
                }

                height: childrenRect.height

                Image {
                    id: nk_logo
                    anchors.left: parent.left
                    width: 90
                    height: width
                    fillMode: Image.Stretch
                    smooth: true
                    source: "qrc:images/nk_logo.png"
                }
                
                Label {
                    anchors {
                        left: nk_logo.right
                        right: parent.right
                        leftMargin: settings.largeMargin
                        verticalCenter: nk_logo.verticalCenter
                    }

                    font.pixelSize: settings.fontSizeXXL + settings.fontCorrection
                    font.bold: true
                    text: "Nokioteca <sup>2.0</sup>"
                }

                Text {
                    anchors {
                        top: nk_logo.bottom
                        left: parent.left
                        right: parent.right
                        topMargin: settings.hugeMargin
                    }

                    text: "Nokioteca è un portale interamente dedicato al mondo Nokia. E' nato da un'idea di oissela nel dicembre 2005 e nel tempo è " +
                          "cresciuto tanto da diventare il punto di riferimento italiano sulla rete per tutti gli appassionati di smartphone Nokia. La community " +
                          "della Nokioteca conta oltre 415.000 iscritti."

                    color: window.platformWhite ? settings.darkColor : settings.lightColor
                    wrapMode: Text.WordWrap
                    font.pixelSize: settings.fontSizeL + settings.fontCorrection
                }
            }
        }

        Text {
            id: supportLink
            anchors {
                bottom: separatorLine.top
                left: parent.left
                bottomMargin: settings.largeMargin
            }

            font.pixelSize: settings.fontSizeM + settings.fontCorrection
            text: "<a href=\"http://www.nokioteca.net/home/forum/index.php/topic/225946-nokioteca-20-consigli-commenti-supporto//\">Supporto</a>"
            onLinkActivated: Qt.openUrlExternally(link)
        }

        Text {
            id: privacyPolicy
            anchors {
                bottom: separatorLine.top
                right: parent.right
                bottomMargin: settings.largeMargin
            }

            font.pixelSize: settings.fontSizeM + settings.fontCorrection
            text: "<a href=\"http://www.nokioteca.net/blog/note-legali/\">Privacy Policy</a>"
            onLinkActivated: Qt.openUrlExternally(link)
        }

        Rectangle {
            id: separatorLine

            anchors {
                right: parent.right
                left: parent.left
                bottom: infoRow.top
                bottomMargin: settings.smallMargin
                leftMargin: settings.hugeMargin
                rightMargin: settings.hugeMargin
            }

            border.color: window.platformWhite ? settings.darkColor : settings.lightColor
            height: 2
        }

        Item {
            id: infoRow
            anchors {
                bottom: parent.bottom
                left: parent.left
                right: parent.right
            }

            height: 25

            Label {
                id: versionLabel
                anchors {
                    right: parent.right
                    verticalCenter: parent.verticalCenter
                }

                font.pixelSize: settings.fontSizeXS
                text: "v" + nokiotecaAppVersion + " by Ices_Eyes"
            }
        }
    }

    tools: ToolBarLayout {
        id: toolBarLayoutDescription

        ToolIcon {
            iconId: "toolbar-back"
            
            anchors.left: (parent === undefined ? undefined : parent.left)
            onClicked: {
                if(busyIndicator)
                    busyIndicator.opacity = 0;
                smallMenu.close();
                aboutPage.pageStack.pop();
            }
        }

        ToolIcon {
            iconId: "toolbar-view-menu"
            
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (smallMenu.status == DialogStatus.Closed) ? smallMenu.open() : smallMenu.close()
        }
    }
}
