import QtQuick 1.1
import QtWebKit 1.0
import com.nokia.meego 1.0

import "script/facebook.js" as Facebook
import "script/twitter.js" as Twitter

Item {
    id: loginDialog

    signal finished(string url)
    signal loadFailed()
    property string authUrl: ""

    anchors.fill: parent

    function loadFacebookLoginPage() {
        if(state == "Facebook")
            webView.url = authUrl;
    }

    function loadTwitterLoginPage(token) {
        if(state == "Twitter") {
            webView.url = authUrl + token;
        }
    }

    onVisibleChanged: {
        if(!visible) {
            webView.url = "";
            webView.html = "";
        }
        else {
            if(busyIndicator)
                busyIndicator.opacity = 0;
        }
    }

    Item {
        id: closeButton
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: settings.smallMargin
            topMargin: settings.smallMargin
        }
        width: 30
        height: 30
        z: 5

        Rectangle {
            anchors.fill: parent
            color: "black"
            radius: 15
        }

        Image {
            anchors.centerIn: parent
            fillMode: Image.PreserveAspectFit
            source: "qrc:images/close.svg"
            sourceSize.height: parent.height - 10
            smooth: true
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                loginDialog.visible = false;
            }
        }
    }

    Rectangle {
        id: borderRectangle
        anchors.centerIn: parent
        height: parent.height - 20
        width: parent.width - 20
        opacity: 0.5
        color: window.platformWhite ? settings.darkColor : settings.lightColor
        radius: 10
    }

    Item {
        anchors.centerIn: borderRectangle
        width: borderRectangle.width - 20
        height: borderRectangle.height - 20

        clip: true

        Flickable {
            id: flickableWebView

            anchors.centerIn: parent
            width: parent.width
            height: parent.height
            contentWidth: Math.max(parent.width, webView.width)
            contentHeight: Math.max(parent.height, webView.height)
            pressDelay: 200

            onWidthChanged : {
                // Expand (but not above 1:1) if otherwise would be smaller that available width.
                if(width > webView.width * webView.contentsScale && webView.contentsScale < 1.0)
                    webView.contentsScale = width / webView.width * webView.contentsScale;
            }

            WebView {
                id: webView
                transformOrigin: Item.TopLeft

                smooth: false
                focus: true

                url: ""

                function doZoom(zoom, centerX, centerY) {
                    if(centerX) {
                        var sc = zoom * contentsScale;
                        scaleAnim.to = sc;
                        flickVX.from = flickableWebView.contentX
                        flickVX.to = Math.max(0, Math.min(centerX - flickableWebView.width / 2, webView.width * sc - flickableWebView.width))
                        finalX.value = flickVX.to
                        flickVY.from = flickableWebView.contentY
                        flickVY.to = Math.max(0, Math.min(centerY - flickableWebView.height/2,webView.height*sc-flickableWebView.height))
                        finalY.value = flickVY.to
                        quickZoom.start()
                    }
                }

                preferredWidth: flickableWebView.width
                preferredHeight: flickableWebView.height
                contentsScale: 1

                onContentsSizeChanged: {
                    // zoom out
                    contentsScale = Math.min(1, flickableWebView.width / contentsSize.width)
                }

                onUrlChanged: {
                    flickableWebView.contentX = 0
                    flickableWebView.contentY = 0
                }

                onDoubleClick: {
                    if(!heuristicZoom(clickX, clickY, 2.5)) {
                        var zf = flickableWebView.width / contentsSize.width
                        if(zf >= contentsScale)
                            zf = 2.0*contentsScale // zoom in (else zooming out)
                        doZoom(zf,clickX*zf,clickY*zf)
                    }
                }

                onLoadStarted: {
                    if(busyIndicator && url.length > 0)
                        busyIndicator.opacity = 0;

                    loadingIndicator.visible = true;
                    if(visible && busyIndicator.opacity > 0)
                        busyIndicator.opacity = 0;
                }

                onLoadFinished: {
                    var jsRedirect = false;
                    if(html.match('<script type="text/javascript">')) {
                        var target_arr = html.match(/window\.location\.href="(.*)"/)
                        if(target_arr){
                            var crappy_target_url = target_arr[1]; // formatting is: http:\/\/www.facebook.com\/
                            var actual_target_url = crappy_target_url.replace(/\\\//g, "/").replace("\u00257C", "|");  // fix formatting
                            url = actual_target_url; // and go there.
                            jsRedirect = true;
                        }
                    }
                    if(!jsRedirect) {
                        loadingIndicator.visible = false;
                        loginDialog.finished(webView.url);
                    }
                }

                onLoadFailed: {
                    loadingIndicator.visible = false;
                    loginDialog.loadFailed();
                }

                SequentialAnimation {
                    id: quickZoom
                    PropertyAction {
                        target: webView
                        property: "renderingEnabled"
                        value: false
                    }
                    ParallelAnimation {
                        NumberAnimation {
                            id: scaleAnim
                            target: webView
                            property: "contentsScale"
                            // the to property is set before calling
                            easing.type: Easing.Linear
                            duration: 200
                        }
                        NumberAnimation {
                            id: flickVX
                            target: flickableWebView
                            property: "contentX"
                            easing.type: Easing.Linear
                            duration: 200
                            from: 0 // set before calling
                            to: 0 // set before calling
                        }
                        NumberAnimation {
                            id: flickVY
                            target: flickableWebView
                            property: "contentY"
                            easing.type: Easing.Linear
                            duration: 200
                            from: 0 // set before calling
                            to: 0 // set before calling
                        }
                    }
                    // Have to set the contentXY, since the above 2
                    // size changes may have started a correction if
                    // contentsScale < 1.0.
                    PropertyAction {
                        id: finalX
                        target: flickableWebView
                        property: "contentX"
                        value: 0 // set before calling
                    }
                    PropertyAction {
                        id: finalY
                        target: flickableWebView
                        property: "contentY"
                        value: 0 // set before calling
                    }
                    PropertyAction {
                        target: webView
                        property: "renderingEnabled"
                        value: true
                    }
                }

                onZoomTo: doZoom(zoom,centerX,centerY)
            }
        }

        ScrollDecorator {
            flickableItem: flickableWebView
        }
    }

    Rectangle {
        id: loadingIndicator
        width: 200
        height: 40
        anchors.centerIn: parent
        color: "#333"
        visible: false

        Text {
            id: textIndicator
            text: "Caricamento..."
            anchors.centerIn: parent
            font.pixelSize: settings.fontSizeL
            color: "#fff"
            wrapMode: Text.WordWrap
        }
    }

    states: [
        State {
            name: "Facebook"
            PropertyChanges {
                target: loginDialog
                authUrl: "https://www.facebook.com/dialog/oauth?client_id=" + nokioteca.getFacebookAppId() +
                         "&redirect_uri=" + nokioteca.getSocialCallbackUrl() +//+ encodeURIComponent(nokioteca.getSocialCallbackUrl()) +
                         "&scope=publish_actions";//&display=popup";
            }
        },
        State {
            name: "Twitter"
            PropertyChanges {
                target: loginDialog
                authUrl: "https://api.twitter.com/oauth/authorize?oauth_token=";
            }
        }
    ]
}
