import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: categoriesListContainer

    property bool showAllNewsPlaceholder: false

    signal itemClicked(int catId, string catTitle);

    Label {
        id: loadCategoriesError
        width: parent.width - 20
        anchors.centerIn: parent
        opacity: 0
        font.pixelSize: settings.fontSizeL + settings.fontCorrection
        wrapMode: Text.WordWrap
        color: settings.errorColor
        z: 100
    }

    XmlListModel {
        id: categoriesModel

        query: "/root/item"

        XmlRole {
            name: "categoryId"
            query: "id/number()"
            isKey: true
        }
        XmlRole {
            name: "categoryTitle"
            query: "title/string()"
        }

        onStatusChanged: {
            if(status == XmlListModel.Loading) {
                if(busyIndicator)
                    busyIndicator.opacity = 1;
                return;
            }
            if(status == XmlListModel.Ready) {
                if(busyIndicator)
                    busyIndicator.opacity = 0;

                // If there are no search results, tell it to the user.
                if(categoriesListView.count === 0) {
                    itemClicked(-2, "");
                }
                else {
                    loadCategoriesError.opacity = 0;
                }
                return;
            }
            if(status == XmlListModel.Error) {
                if(busyIndicator)
                    busyIndicator.opacity = 0;

                loadCategoriesError.text = "Si è verificato un errore nel recupero delle categorie.\n" +
                        "Verifica di essere connesso ad internet e che i server di " +
                        "Nokioteca.net siano funzionanti.";
                loadCategoriesError.opacity = 1;
            }
        }
    }

    Component {
        id: categoryItem

        Item {
            id: root
            width: parent.width
            height: childrenRect.height

            Item {
                id: allNewInCatListItem

                BorderImage {
                    id: background1
                    anchors.fill: parent
                    // Fill page borders
                    anchors.leftMargin: -categoriesListContainer.anchors.leftMargin
                    anchors.rightMargin: -categoriesListContainer.anchors.rightMargin
                    visible: listItemMouseArea1.pressed
                    source: "image://theme/meegotouch-list" + (theme.inverted ? "-inverted" : "") + "-background-pressed-center"
                }

                Rectangle {
                    height: 1
                    color: theme.inverted ? "#444444" : "#A9A9A9"
                    anchors {
                        bottom: parent.bottom
                        left: parent.left
                        right: parent.right
                    }
                }

                width: parent.width
                height: 70
                
                visible: showAllNewsPlaceholder && (index === 0)

                Label {
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: settings.largeMargin
                        verticalCenter: parent.verticalCenter
                    }
                    text: "Tutte le notizie"
                    font.pixelSize: settings.fontSizeL + settings.fontCorrection
                }

                Image {
                     source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                     anchors.right: parent.right
                     anchors.verticalCenter: parent.verticalCenter
                 }

                MouseArea {
                    id: listItemMouseArea1
                    anchors.fill: background1

                    onClicked: {
                        // Item selected
                        if(busyIndicator)
                            busyIndicator.opacity = 1;
                        categoriesListView.currentIndex = index;
                        categoriesListContainer.itemClicked(-1, "");
                    }
                }
            }

            Item {
                id: categoryListItem

                BorderImage {
                    id: background2
                    anchors.fill: parent
                    // Fill page borders
                    anchors.leftMargin: -categoriesListContainer.anchors.leftMargin
                    anchors.rightMargin: -categoriesListContainer.anchors.rightMargin
                    visible: listItemMouseArea2.pressed
                    source: "image://theme/meegotouch-list" + (theme.inverted ? "-inverted" : "") + "-background-pressed-center"
                }

                Rectangle {
                    height: 1
                    color: theme.inverted ? "#444444" : "#A9A9A9"
                    anchors {
                        bottom: parent.bottom
                        left: parent.left
                        right: parent.right
                    }
                }
                
                anchors.top: allNewInCatListItem.visible ? allNewInCatListItem.bottom : parent.top
                width: parent.width
                height: 70

                Label {
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: settings.largeMargin
                        verticalCenter: parent.verticalCenter
                    }
                    text: categoryTitle
                    font.pixelSize: settings.fontSizeL + settings.fontCorrection
                }

                Image {
                     source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                     anchors.right: parent.right
                     anchors.verticalCenter: parent.verticalCenter
                }

                MouseArea {
                    id: listItemMouseArea2
                    anchors.fill: background2

                    onClicked: {
                        // Item selected
                        if(busyIndicator)
                            busyIndicator.opacity = 1;
                       categoriesListView.currentIndex = index;
                       categoriesListContainer.itemClicked(categoryId, categoryTitle);
                    }
                }
            }
            
            ListView.onRemove: SequentialAnimation {
                PropertyAction { target: root; property: "ListView.delayRemove"; value: true }
                NumberAnimation {
                    target: root
                    property: "opacity"
                    from: 1
                    to: 0
                    duration: 200
                    easing.type: Easing.Linear
                }
                PropertyAction { target: root; property: "ListView.delayRemove"; value: false }
            }

            ListView.onAdd: NumberAnimation {
                target: root
                property: "opacity"
                from: 0
                to: 1
                duration: 250
                easing.type: Easing.Linear
            }
        }
    }


    ListView {
        id: categoriesListView

        anchors.fill: parent
        snapMode: ListView.SnapToItem
        clip: true
        model: categoriesModel
        delegate: categoryItem

    }

    ScrollDecorator {
        flickableItem: categoriesListView
    }

    /* Get the available categories */
    function getCategories() {
        var url = nokioteca.getCategoriesUrl();
        categoriesModel.source = url;
    }

    /* Get the available subcategories */
    function getSubcategories(catId) {
        var url = nokioteca.getSubCategoriesUrl(catId);
        categoriesModel.source = url;
    }
}
