import QtQuick 1.1

ListModel {
    id: root

    property alias source: xmlListModel.source
    property alias query: xmlListModel.query
    property alias namespaceDeclarations: xmlListModel.namespaceDeclarations

    property alias status: xmlListModel.status

    property bool threadedComments: true

    function push(item) {
        append(item);
    }

    function reload() {
        xmlListModel.reload();
    }

    function errorString() {
        return xmlListModel.errorString();
    }

    function changeCommentsSorting(byTime) {
        threadedComments = !byTime;

        if(count > 1) {
            root.clear();
            xmlListModel.reconstructCommentsTree();
        }
    }

    property variant __xmlListModel: XmlListModel {
        id: xmlListModel

        XmlRole {
            name: "commentId"
            query: "id/number()"
            isKey: true
        }

        XmlRole {
            name: "commentAuthor"
            query: "author/string()"
        }

        XmlRole {
            name: "commentText"
            query: "comment/string()"
        }

        XmlRole {
            name: "commentDate"
            query: "date/string()"
        }

        XmlRole {
            name: "parentId"
            query: "parent/number()"
        }

        XmlRole {
            name: "authorAvatar"
            query: "avatar/img/@src/string()"
        }

        property variant keys: []

        function addToModel(root, level) {
            if(!root)
                return;
            for(var i = 0; i < root.length; i++) {
                var item = root[i];
                item.commentLevel = level;
                push(item);
                addToModel(root[i].children, level + 1);
            }
            return;
        }

        function reconstructCommentsTree() {
            var item;

            if(xmlListModel.count === 0) {
                item = new Object();
                item.commentId  = -1;
                item.commentAuthor = "";
                item.authorAvatar = "";
                item.commentText = "";
                item.commentDate = "";
                item.commentLevel = 0;
                push(item);
                return;
            }

            if(threadedComments) {
                item = new Object();
                var itemMap = new Object();
                var tree = [];
                for(var i = 0; i < xmlListModel.count; i++) {
                    item = xmlListModel.get(i);
                    item.children = [];

                    if(item.parentId === 0)
                        tree.push(item);
                    else
                        itemMap['c_' + item.parentId].children.push(item);
                    itemMap['c_' + item.commentId] = item;
                }
                addToModel(tree, 0);
            }
            else {
                for(var i = 0; i < xmlListModel.count; i++) {
                    item = xmlListModel.get(i);
                    item.commentLevel = 0;
                    push(item);
                }
            }
        }

        onItemsInserted: {
            root.clear();
            reconstructCommentsTree();
        }
    }

    Component.onCompleted: {
        var keys = new Array()
        for(var i = 0; i < xmlListModel.roles.length; i++) {
            if(xmlListModel.roles[i].isKey) {
                keys.push(xmlListModel.roles[i].name);
            }
        }
        xmlListModel.keys = keys;
    }
}
