import QtQuick 1.1
import com.nokia.meego 1.0

Dialog {
    id: root
    objectName: "commonDialog"

    property string titleText: ""
    property alias titleIcon: iconImage.source
    property variant buttonTexts: []

    signal buttonClicked(int index)

    platformStyle: DialogStyle {
        property int contentMargin: 21
        leftMargin: settings.largeMargin
        rightMargin: settings.largeMargin
    }
    title: Item {
        id: titleField
        width: parent.width
        height: titleText == "" ? titleBarIconField.height :
                    titleBarIconField.height + titleTextText.height + titleFieldCol.spacing
        Column {
            id: titleFieldCol
            anchors { left: parent.left; right:  parent.right; top:  parent.top }
            spacing: 17

            Item {
                id: titleBarIconField
                anchors { left: parent.left; right: parent.right }
                height: iconImage.height

                Image {
                    id: iconImage
                    anchors.horizontalCenter: titleBarIconField.horizontalCenter
                }
            }

            Item {
                id: titleBarTextField
                anchors { left: parent.left; right: parent.right }
                height: titleTextText.height

                Text {
                    id: titleTextText
                    anchors { left: parent.left; right: parent.right }
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    font.pixelSize: settings.fontSizeXXL
                    font.bold: true
                    color: "white"
                    elide: root.platformStyle.titleElideMode
                    wrapMode: elide == Text.ElideNone ? Text.Wrap : Text.NoWrap
                    text: root.titleText
                }
            }
        }
    }

    buttons: Item {
        anchors { left: parent.left; right: parent.right }
        height: buttonCol.height + buttonCol.anchors.topMargin

        Column {
            id: buttonCol
            anchors {
                top: parent.top
                topMargin: root.platformStyle.buttonsTopMargin
                horizontalCenter: parent.horizontalCenter
            }
            spacing: root.platformStyle.buttonsColumnSpacing
            height: childrenRect.height

            Repeater {
                model: buttonTexts

                Button {
                    text: modelData
                    onClicked: {
                        buttonClicked(index)
                        if (index === 0) accept()
                        else reject()
                    }
                    platformStyle: ButtonStyle {
                        inverted: true
                        background: index === 0 ? "image://theme/meegotouch-dialog-button-positive"
                                                : "image://theme/meegotouch-dialog-button-negative"
                        pressedBackground: index === 0 ? "image://theme/meegotouch-dialog-button-positive-pressed"
                                                       : "image://theme/meegotouch-dialog-button-negative-pressed"
                    }
                }
            }
        }
    }
}
