import QtQuick 1.1
import com.nokia.meego 1.0

import "script/settings.js" as AppSettings

Page {
    id: favouritesNewsPage

    property bool isWindowsteca: false
    
    TopBar {
        id: nk_banner
        anchors.top: parent.top
        isWindowsteca: parent.isWindowsteca
    }

    Label {
        id: favouritesLabel

        anchors {
            top: nk_banner.bottom
            right: parent.right
            left: parent.left
        }
        wrapMode: Text.WordWrap
        font.pixelSize: settings.fontSizeL + settings.fontCorrection
        text: "I tuoi articoli preferiti:";
    }

    Rectangle {
        id: separatorLine

        anchors {
            top: favouritesLabel.bottom
            right: parent.right
            left: parent.left
            topMargin: settings.smallMargin
            leftMargin: settings.smallMargin
            rightMargin: settings.smallMargin
        }

        border.color: window.platformWhite ? settings.darkColor : settings.lightColor
        height: 2
    }

    Label {
        id: noFavouritesLabel

        anchors {
            top: separatorLine.bottom
            right: parent.right
            bottom: parent.bottom
            left: parent.left
        }
        visible: !favouritesNewsView.visible
        wrapMode: Text.WordWrap
        font.pixelSize: settings.fontSizeL + settings.fontCorrection
        text: "Non hai ancora inserito alcun preferito. Utilizza la stellina in testa a ogni articolo per farlo.";
    }

    NewsListView {
        id: favouritesNewsView
        
        anchors {
            top: separatorLine.bottom
            right: parent.right
            bottom: parent.bottom
            left: parent.left
        }
        
        isWindowsteca: parent.isWindowsteca
        
        /*Component.onCompleted: {
            var favsList = AppSettings.getFavouritesIds(isWindowsteca);
            if(favsList.length > 1)
                getFavouritesNews(favsList);
            else
                visible = false;
        }*/

        onItemClicked: {
            if(!favouritesNewsPage.pageStack.busy) {
                var detailsPage =
                        favouritesNewsPage.pageStack.push(Qt.resolvedUrl("SingleNewsPage.qml"),
                                                  { newsId: id, commentsCount: comments, isWindowsteca: isWindowsteca });
                detailsPage.fetchDetails(id);
            }
        }
    }

    tools: ToolBarLayout {
        id: toolBarLayoutDescription

        ToolIcon {
            iconId: "toolbar-back"

            anchors.left: (parent === undefined) ? undefined : parent.left
            onClicked: {
                if(busyIndicator)
                    busyIndicator.opacity = 0;
                smallMenu.close();
                favouritesNewsPage.pageStack.pop();
            }
        }

        ToolIcon {
            iconSource: "qrc:images/unfavourite" + (window.platformWhite ? "_w" : "") + ".svg"

            enabled: favouritesNewsView.visible
            opacity: enabled ? 1 : 0.3

            onClicked: {
                smallMenu.close();
                confirmDialog.open();
            }
        }

        ToolIcon {
            iconId: "toolbar-view-menu"

            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (appMenu.status == DialogStatus.Closed) ? smallMenu.open() : smallMenu.close()
        }
    }

    QueryDialog {
        id: confirmDialog

        titleText: "Eliminazione dei preferiti"
        message: "Si vogliono eliminare tutti i preferiti di " +
                 (isWindowsteca ? "Windowsteca.net" : "Nokioteca.net") +
                 " salvati fin'ora?"
                 
        acceptButtonText: "Sì"
        rejectButtonText: "No"

        onAccepted: {
            AppSettings.removeFavourites(isWindowsteca);
            infoBanner.text = "Preferiti correttamente eliminati"
            infoBanner.iconSource = "qrc:images/ok.png";
            infoBanner.show();
            favouritesNewsPage.pageStack.pop(null);
        }
    }
    
    function getFavouritesNews() {
        var favsList = AppSettings.getFavouritesIds(isWindowsteca);
        if(favsList.length > 1)
            favouritesNewsView.getFavouritesNews(favsList)
        else
            favouritesNewsView.visible = false;
    }
}
