import QtQuick 1.1
import com.nokia.meego 1.0

import "script/settings.js" as AppSettings
import "TextComponent"

Dialog {
    id: root
    objectName: "queryDialog"

    property string titleText
    property string message

    //are they necessary?
    property alias acceptButtonText: acceptButton.text
    property alias rejectButtonText: rejectButton.text

    //ToDo
    property alias icon: iconImage.source

    property Style platformStyle: QueryDialogStyle {}

    //__centerContentField: true

    __dim: platformStyle.dim
    __fadeInDuration:  platformStyle.fadeInDuration
    __fadeOutDuration: platformStyle.fadeOutDuration
    __fadeInDelay:     platformStyle.fadeInDelay
    __fadeOutDelay:    platformStyle.fadeOutDelay

    __animationChief: "queryDialog"

    //Deprecated, TODO Remove this on w13
    property alias style: root.platformStyle

    signal linkActivated(string link)

    signal checkedAndAccepted(string userName, string userMail, string userSite, string userComment)

    // the title field consists of the following parts: title string and
    // a close button (which is in fact an image)
    // it can additionally have an icon
    title: Item {
        id: titleField
        width: parent.width
        height: titleText == "" ? titleBarIconField.height :
                    titleBarIconField.height + titleLabel.height + root.platformStyle.titleColumnSpacing
        Column {
            id: titleFieldCol
            spacing: root.platformStyle.titleColumnSpacing

            anchors.left:  parent.left
            anchors.right:  parent.right
            anchors.top:  parent.top

            width: root.width

            Item {
                id: titleBarIconField
                height: iconImage.height
                width: parent.width
                Image {
                    id: iconImage
                    anchors.horizontalCenter: titleBarIconField.horizontalCenter
                    source: ""
                }

            }

            Item {
                id: titleBarTextField
                height: titleLabel.height
                width: parent.width

                Text {
                    id: titleLabel
                    width: parent.width

                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment:   Text.AlignVCenter

                    font.family: root.platformStyle.titleFontFamily
                    font.pixelSize: root.platformStyle.titleFontPixelSize
                    font.bold:  root.platformStyle.titleFontBold
                    font.capitalization: root.platformStyle.titleFontCapitalization
                    elide: root.platformStyle.titleElideMode
                    wrapMode: elide == Text.ElideNone ? Text.Wrap : Text.NoWrap
                    color: root.platformStyle.titleTextColor
                    text: root.titleText

                }
            }

            // needed for animation
            transform: Scale {
                id: titleScale
                xScale: 1.0; yScale: 1.0
                origin.x: mapFromItem(queryContent, queryContent.width / 2, queryContent.height / 2).x
                origin.y: mapFromItem(queryContent, queryContent.width / 2, queryContent.height / 2).y
            }

        }
    }

    // the content field which contains the message text
    content: Item {
        id: queryContentWrapper

        property int upperBound: visualParent ? visualParent.height - titleField.height - buttonColFiller.height - 64
                                                : root.parent.height - titleField.height - buttonColFiller.height - 64
        property int __sizeHint: Math.min(Math.max(root.platformStyle.contentFieldMinSize, inputFields.height), upperBound)

        height: __sizeHint + root.platformStyle.contentTopMargin
        width: root.width

        Item {
            id: queryContent
            width: parent.width

            y: root.platformStyle.contentTopMargin

            Flickable {
                id: queryFlickable
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                height: queryContentWrapper.__sizeHint

                contentHeight: inputFields.height
                flickableDirection: Flickable.VerticalFlick
                clip: true

                interactive: inputFields.height > queryContentWrapper.__sizeHint

                Column {
                    id: inputFields

                    spacing: 5

                    width: queryFlickable.width

                    Label {
                        id: errorsOnData

                        anchors {
                            left: parent.left
                            right: parent.right
                        }

                        wrapMode: Text.WordWrap
                        font.pixelSize: settings.fontSizeM
                        color: settings.errorColor
                        opacity: (text.length > 0 ? 1 : 0)
                    }

                    Label {
                        id: replyToData

                        anchors {
                            left: parent.left
                            right: parent.right
                        }

                        opacity: 0
                        color: settings.lightColor
                        font.pixelSize: settings.fontSizeS
                    }

                    TextField {
                        id: userNameText

                        anchors {
                            left: parent.left
                            right: parent.right
                        }

                        maximumLength: 30
                        placeholderText: "Inserisci il tuo nome*"
                    }

                    TextField {
                        id: userMailText

                        anchors {
                            left: parent.left
                            right: parent.right
                        }

                        maximumLength: 30
                        validator: RegExpValidator{regExp: /^\w([a-zA-Z0-9.!#$%&'*+-\/=?^_`{|}~]+)*@\w+([\.-]?\w+)*(\.\w{2,4})+$/}
                        placeholderText: "Inserisci la tua e-mail*"
                    }

                    TextField {
                        id: userSiteText

                        anchors {
                            left: parent.left
                            right: parent.right
                        }

                        maximumLength: 30
                        placeholderText: "Inserisci il tuo sito web"
                    }

                    MyTextArea {
                        id: theComment

                        anchors {
                            left: parent.left
                            right: parent.right
                        }

                        horizontalAlignment: Text.AlignLeft

                        textFormat: Text.PlainText

                        placeholderText: "Inserisci il commento*"

                        height: 100

                        onActiveFocusChanged: if(activeFocus) {
                                            if(queryFlickable.contentHeight > queryFlickable.height)
                                                queryFlickable.contentY = queryFlickable.contentHeight - queryFlickable.height
                        }
                    }
                }
            }

            Connections {
                target: inputContext
                onSoftwareInputPanelVisibleChanged: if(theComment.activeFocus)
                                                        queryFlickable.contentY = queryFlickable.contentHeight - queryFlickable.height
            }

            ScrollDecorator {
                id: scrollDecorator
                flickableItem: queryFlickable
            }

        }
    }

    buttons: Item {
        id: buttonColFiller
        width: parent.width
        height: childrenRect.height

        anchors.top: parent.top

        //ugly hack to assure, that we're always evaluating the correct height
        //otherwise the topMargin wouldn't be considered
        Item {id: dummy; anchors.fill:  parent}

        ButtonRow {
            id: buttonCol
            anchors {
                top: parent.top
                topMargin: root.platformStyle.buttonTopMargin
                horizontalCenter: parent.horizontalCenter
            }

            exclusive: false

            Button {
                id: rejectButton
                text: ""
                onClicked: {
                    theComment.closeSoftwareInputPanel();
                    reject();
                }
                visible: text != ""
                //__dialogButton: true
                platformStyle: ButtonStyle {
                    inverted: true
                    background: "image://theme/meegotouch-dialog-button-negative"
                    pressedBackground: "image://theme/meegotouch-dialog-button-negative-pressed"
                }
            }

            Button {
                id: acceptButton
                text: ""
                visible: text != ""
                //__dialogButton: true
                platformStyle: ButtonStyle {
                    inverted: true
                    background: "image://theme/meegotouch-dialog-button-positive"
                    pressedBackground: "image://theme/meegotouch-dialog-button-positive-pressed"
                }

                onClicked: {
                    var theErrors = "";
                    theComment.closeSoftwareInputPanel();
                    if(userNameText.text.trim().length === 0) {
                        userNameText.errorHighlight = true;
                        theErrors += "Il tuo nome è obbligatorio.\n";
                    }

                    if(!userMailText.acceptableInput)
                        theErrors += "L'indirizzo e-mail deve essere valido.\n";

                    if(theComment.text.trim().length === 0) {
                        theErrors += "Il tuo commento non può essere vuoto.\n";
                    }

                    if(theErrors.length > 0) {
                        errorsOnData.text = theErrors;
                        return;
                    }
                    errorsOnData.text = "";
                    userNameText.errorHighlight = false;

                    close();
                    checkedAndAccepted(userNameText.text.trim(), userMailText.text.trim(),
                                       userSiteText.text.trim(), theComment.text.trim());
                }
            }
        }
    }

    function setReplyToText(newText) {
        errorsOnData.text = "";
        userNameText.errorHighlight = false;
        theComment.text = "";
        replyToData.text = newText;
        if(newText.length > 0) {
            replyToData.opacity = 1;
            titleText = "Nuova risposta";
        }
        else {
            replyToData.opacity = 0;
            titleText = "Nuovo commento";
        }
    }

    Component.onCompleted: {
        userNameText.text = AppSettings.getLastUsedName();
        userMailText.text = AppSettings.getLastUsedMail();
        userSiteText.text = AppSettings.getLastUsedSite();
    }

    StateGroup {
        id: statesWrapper

        state: "__query__hidden"

        // needed for button animation
        // without resetting the button row's coordinate system would be translated
        property int __buttonSaver: buttonColFiller.y

        states: [
            State {
                name: "__query__visible"
                when: root.__animationChief == "queryDialog" && (root.status == DialogStatus.Opening || root.status == DialogStatus.Open)
                PropertyChanges {
                    target: root
                    opacity: 1.0
                }
                PropertyChanges {
                    target: newsDetailPage
                    orientationLock: PageOrientation.LockPortrait
                }
                PropertyChanges {
                    target: screen
                    allowedOrientations: Screen.Portrait;
                }
            },
            State {
                name: "__query__hidden"
                when: root.__animationChief == "queryDialog" && (root.status == DialogStatus.Closing || root.status == DialogStatus.Closed)
                PropertyChanges {
                    target: root
                    opacity: 0.0
                }
                PropertyChanges {
                    target: newsDetailPage
                    orientationLock: PageOrientation.Automatic
                }
                PropertyChanges {
                    target: screen
                    allowedOrientations: Screen.Landscape | Screen.Portrait;
                }
            }
        ]

        transitions: [
            Transition {
                from: "__query__visible"; to: "__query__hidden"
                SequentialAnimation {
                    ScriptAction {script: {
                            __fader().state = "hidden";
                            root.opacity = 1.0;
                            queryContent.opacity = 1.0
                            titleField.opacity = 1.0

                            statesWrapper.__buttonSaver = buttonColFiller.y
                            root.status = DialogStatus.Closing;

                        }
                    }

                    NumberAnimation { target: root; properties: "opacity"; from: 0.0; to: 1.0; duration: 0 }
                    NumberAnimation { target: queryContent; properties: "opacity"; from: 0.0; to: 1.0; duration: 0 }
                    NumberAnimation { target: titleField; properties: "opacity"; from: 0.0; to: 1.0; duration: 0 }

                    // The closing transition fades out the dialog's content from 100% to 0%,
                    // scales down the content to 80% anchored in the center over 175msec, quintic ease in,
                    // then, after a 175ms delay the background fades to alpha 0% (350ms, quintic ease out).
                    // (background fading is done in Fader.qml)

                    ParallelAnimation {
                        NumberAnimation {target: queryContent; properties: "opacity"; from: 1.0; to: 0.0; duration: 175}
                        NumberAnimation {target: titleField; properties: "opacity"; from: 1.0; to: 0.0; duration: 175}
                        NumberAnimation {target: titleScale; properties: "xScale,yScale"; from: 1.0 ; to: 0.8; duration: 175; easing.type: Easing.InQuint}
                        NumberAnimation {target: queryContent; property: "scale"; from: 1.0 ; to: 0.8; duration: 175; easing.type: Easing.InQuint}
                        NumberAnimation {target: buttonColFiller; properties: "opacity"; from: 1.0; to: 0.0; duration: 175}
                        NumberAnimation {target: buttonColFiller; property: "scale"; from: 1.0 ; to: 0.8; duration: 175; easing.type: Easing.InQuint}
                    }

                    ScriptAction {script: {

                            // reset button
                            buttonColFiller.y = statesWrapper.__buttonSaver

                            // make sure, root isn't visible:
                            root.opacity = 0.0;
                            status = DialogStatus.Closed;

                        }
                    }

                }
            },
            Transition {
                from: "__query__hidden"; to: "__query__visible"
                SequentialAnimation {
                    ScriptAction {script: {
                            __fader().state = "visible";

                            statesWrapper.__buttonSaver = buttonColFiller.y

                            root.status = DialogStatus.Opening;
                            // UPPERCASE-UGLY, but necessary to avoid flicker
                            root.opacity = 1.0
                            titleField.opacity = 0.0
                            queryContent.opacity = 0.0
                            buttonColFiller.opacity = 0.0
                        }
                    }

                    // The opening transition fades in from 0% to 100% and at the same time
                    // scales in the content from 80% to 100%, 350msec, anchored in the center
                    // cubic ease out). --> Done inside the fader

                    ParallelAnimation {
                        NumberAnimation {target: queryContent; properties: "opacity"; from: 0.0; to: 1.0; duration: 350; easing.type: Easing.OutCubic; }
                        NumberAnimation {target: titleField; properties: "opacity"; from: 0.0; to: 1.0; duration: 350; easing.type: Easing.OutCubic; }
                        NumberAnimation {target: titleScale; properties: "xScale,yScale"; from: 0.8 ; to: 1.0; duration: 350; easing.type: Easing.OutCubic; }
                        NumberAnimation {target: queryContent; property: "scale"; from: 0.8 ; to: 1.0; duration: 350; easing.type: Easing.OutCubic; }
                        NumberAnimation {target: buttonColFiller; property: "scale"; from: 0.8 ; to: 1.0; duration: 350; easing.type: Easing.OutCubic; }
                        NumberAnimation {target: buttonColFiller; properties: "opacity"; from: 0.0; to: 1.0; duration: 350; easing.type: Easing.OutCubic; }
                    }

                    ScriptAction {script: {
                            // reset button
                            buttonColFiller.y = statesWrapper.__buttonSaver
                            root.status = DialogStatus.Open;
                        }
                    }
                }
            }
        ]
    }
}
