import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1

Item {
    id: root

    property string titleText
    property string subtitleText

    property bool subItemIndicator: false
    property bool comboboxItemIndicator: false

    signal clicked()

    height: 80
    width: parent.width

    anchors.margins: settings.smallMargin

    BorderImage {
        id: background
        // Fill page orders
        anchors {
            fill: parent
            leftMargin: -16
            rightMargin: -16
        }

        visible: listItemMouseArea.pressed
        source: "image://theme/meegotouch-list" + (theme.inverted ? "-inverted" : "") + "-background-pressed-center"
    }

    Item {
        anchors {
            fill: parent
            leftMargin: settings.mediumMargin
            rightMargin: iconLoader.status == Loader.Ready ?
                    settings.smallMargin + iconLoader.width + settings.mediumMargin :
                    settings.smallMargin
            topMargin: settings.mediumMargin
            bottomMargin: settings.mediumMargin
        }

        Column {
            id: listItemTexts
            anchors {
                left: parent.left
                right: parent.left
                verticalCenter: parent.verticalCenter
            }

            Label {
                id: mainText
                text: root.titleText
                font.family: "Nokia Pure Text"
                font.weight: Font.Bold
                font.pixelSize: settings.fontSizeXL
                color: theme.inverted ? "#ffffff" : "#191919"
            }

            Label {
                id: subText
                text: root.subtitleText
                font.family: "Nokia Pure Text Light"
                font.weight: Font.Normal
                font.pixelSize: settings.fontSizeL
                color: theme.inverted ? "#8c8c8c" : "#505050"

                visible: text != ""
            }
        }
    }

    Loader {
        id: iconLoader
        sourceComponent: root.subItemIndicator ? subItemIcon : (root.comboboxItemIndicator ? comboboxItemIcon : undefined)
        anchors {
            right: parent.right
            rightMargin: settings.mediumMargin
            verticalCenter: parent.verticalCenter
        }
    }

    Component {
        id: subItemIcon

        Image {
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
        }
    }

    Component {
        id: comboboxItemIcon

        Image {
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            source: theme.inverted ? "image://theme/icon-m-textinput-combobox-arrow"
                                           : "image://theme/icon-m-common-combobox-arrow"
        }
    }

    MouseArea {
        id: listItemMouseArea
        anchors.fill: parent
        onClicked: root.clicked()
    }
}
