﻿import QtQuick 1.1
import com.nokia.meego 1.0

import "script/newcommentinputmask.js" as NewCommentInputMaskFn
import "script/settings.js" as AppSettings
import "script/ajax.js" as AjaxScript

Item {
    id: rootMask
    property int replyToNewsId: -1

    property int replyToParentId: 0

    property bool commentsEnabled: true

    property Item focusedItem

    signal setAsReply(int toPost, string toUser, string toText)

    anchors {
        left: parent.left
        right: parent.right
    }
    
    height: (commentsEnabled ? userComment.height : commentsDisabledInfo.height)

    Label {
        id: commentsDisabledInfo

        anchors {
            left: parent.left
            right: parent.right
            leftMargin: settings.smallMargin
            rightMargin: settings.mediumMargin
            topMargin: settings.mediumMargin
            bottomMargin: settings.mediumMargin
        }

        font.pixelSize: settings.fontSizeL + settings.fontCorrection
        wrapMode: Text.WordWrap
        color: settings.errorColor

        visible: !commentsEnabled
        
        text: "I commenti per questo articolo sono disabilitati."
    }

    Button {
        id: userComment
        anchors.right: parent.right

        visible: commentsEnabled

        width: 180 + 3 * settings.fontCorrection
        height: 40 + settings.fontCorrection
        font.pixelSize: settings.fontSizeL + settings.fontCorrection
        text: "Invia nuovo"

        onClicked: {
            userCommentDialog.setReplyToText("");
            userCommentDialog.open()
        }


    }

    InputDialog {
        id: userCommentDialog

        acceptButtonText: "Invia"
        rejectButtonText: "Annulla"

        onCheckedAndAccepted: {
            NewCommentInputMaskFn.checkAndSendComment(userName, userMail, userSite, userComment);
            userCommentDialog.setReplyToText("");
        }
        onRejected: userCommentDialog.setReplyToText("")
    }

    onSetAsReply: {
        replyToParentId = toPost;
        userCommentDialog.setReplyToText("In risposta a <strong>" + toUser.trim() + "</strong>:<br />\"" + toText.trim() + "...\"");
        userCommentDialog.open()
    }

    QueryDialog {
        id: sendConfirmed

        acceptButtonText: "Ok"
        titleText: "Commento inviato"
        message: "Il tuo commento è stato inviato con successo.\nSe non dovesse comparire nella lista, attendi la sua approvazione."

        onAccepted: refreshComments()
    }

    Loader {
        id: privacyAgreementQueryLoader

        anchors.fill: parent

        function show(userName, userMail, userSite, userComment) {
            if(!item)
                sourceComponent = privacyAgreementQuery;
            item.userName = userName;
            item.userMail = userMail;
            item.userSite = userSite;
            item.userComment = userComment;
            item.open();
        }
    }

    Component {
        id: privacyAgreementQuery
        QueryDialog {
            property string userName
            property string userMail
            property string userSite
            property string userComment

            acceptButtonText: "Accetto"
            rejectButtonText: "Rifiuto"
            titleText: "Informazioni sulla privacy"
            message: "Per l'inserimento di un nuovo commento è necessario l'invio dei tuoi dati personali al server di " +
                     "Nokioteca Blog. I tuoi dati saranno utilizzati al solo scopo di inserire questo e i tuoi futuri " +
                     "commenti e saranno trattati con la massima riservatezza. Una volta inseriti, questi verranno " +
                     "memorizzati dall'applicazione, così da facilitare l'inserimento di ogni tuo commento.\n\n" +
                     "Questo messaggio, se accettato, comparirà una sola volta. Potrai revocare il tuo consenso in " +
                     "qualunque momento selezionando il pulsante \"Elimina dati utente\" presente nella pagina " +
                     "\"Informazioni\" di questa applicazione.\n\n" +
                     "Se non accetti questo messaggio, il tuo commento non potrà essere inserito."

            onAccepted: {
                AppSettings.setPrivacyAgreement(true);
                NewCommentInputMaskFn.checkAndSendComment(userName, userMail, userSite, userComment);
            }

            onRejected: {
                infoBanner.text = "Autorizzazione non concessa"
                infoBanner.iconSource = "qrc:images/ko.png"
                infoBanner.show();
            }
        }
    }
}
