import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1

import "script/settings.js" as AppSettings
import "script/facebook.js" as Facebook
import "script/twitter.js" as Twitter

Page {
    id: settingsUiPage

    anchors.fill: parent

    Flickable {
        id: settingsFlick

        anchors.fill: parent

        /*contentHeight: childrenRect.height*/
        contentHeight: Math.max(settingsPane.height + clearDataSettings.height + 10, settingsUiPage.height)
        
        interactive: contentHeight > height

        Item {
            id: settingsPane
            
            anchors {
                left: parent.left
                right: parent.right
            }

            height: childrenRect.height

            Label {
                id: settingsLabel
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: settings.smallMargin
                }
                font.pixelSize: settings.fontSizeXXL + settings.fontCorrection
                text: "Impostazioni"

                Rectangle {
                    height: 1
                    color: theme.inverted ? "#444444" : "#A9A9A9"

                    anchors {
                        bottom: parent.bottom
                        left: parent.left
                        right: parent.right
                        leftMargin: settings.mediumMargin
                        rightMargin: settings.mediumMargin
                        bottomMargin: -settings.smallMargin
                    }
                }
            }

            Item {
                id: themeChooser
                anchors {
                    left: parent.left
                    right: parent.right
                    top: settingsLabel.bottom
                    topMargin: settings.largeMargin
                }

                height: childrenRect.height
                Column {
                    id: themeColumn
                    anchors{
                        left: parent.left
                        right: parent.right
                        leftMargin: settings.mediumMargin
                        rightMargin: settings.mediumMargin
                    }

                    spacing: settings.smallMargin

                    Label {
                        id: themeTitle
                        anchors {
                            left: parent.left
                            right: parent.right
                            //leftMargin: settings.largeMargin
                        }
                        text: "Stile tema"
                        font.pixelSize: settings.fontSizeXL
                    }

                    ButtonRow {
                        id: buttonRow
                        anchors {
                            left: parent.left
                            right: parent.right
                        }

                        exclusive: true
                        checkedButton: window.platformWhite ? whiteTheme : darkTheme

                        Button {
                            id: darkTheme
                            text: "Scuro"

                            onClicked: {
                                if(checked) {
                                    AppSettings.setTheme(false);
                                    theme.inverted = true;
                                    window.platformWhite = false;
                                }
                            }
                        }

                        Button {
                            id: whiteTheme
                            text: "Chiaro"

                            onClicked: {
                                if(checked) {
                                    AppSettings.setTheme(true);
                                    theme.inverted = false;
                                    window.platformWhite = true;
                                }
                            }
                        }
                    }
                }
            }

            ListItem {
                id: fontCorrectionItem

                anchors.top: themeChooser.bottom

                subItemIndicator: true

                titleText: "Dimensione caratteri"
                subtitleText: settings.fontCorrection === 0 ? "Default" : ((settings.fontCorrection > 0 ? "+" : "") + settings.fontCorrection)

                onClicked: fontSizeDialogLoader.show()
            }

            ListItem {
                id: videoTypeItem

                anchors.top: fontCorrectionItem.bottom

                comboboxItemIndicator: true

                titleText: "Visualizzazione video"
                subtitleText: selectionDialog.model.get(selectionDialog.selectedIndex).shortName

                onClicked: selectionDialog.open()

                SelectionDialog {
                    id: selectionDialog
                    titleText: "Visualizzazione video"
                    selectedIndex: AppSettings.getSelectedVideoType() - 1
                    model: ListModel {
                        ListElement { modelData: "Nell'applicazione\n(se disponibile - bassa qualità)"; shortName: "Nell'applicazione" }
                        ListElement { modelData: "Nel browser web"; shortName: "Nel browser web"}
                        ListElement { modelData: "Chiedi sempre"; shortName: "Chiedi sempre" }
                    }

                    onAccepted:
                        AppSettings.setSelectedVideoType(selectedIndex + 1);

                    onRejected:
                        selectedIndex = AppSettings.getSelectedVideoType() - 1;
                }
            }

            Item {
                id: automaticFavs

                anchors {
                    left: parent.left
                    right: parent.right
                    top: videoTypeItem.bottom
                    topMargin: settings.largeMargin
                }

                height: childrenRect.height

                Item {
                    id: autoFavSetting

                    height: Math.max(autoFavsLabel.height, automaticFavsCheckBox.height)

                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: settings.mediumMargin
                        rightMargin: settings.mediumMargin
                    }

                    Label {
                        id: autoFavsLabel
                        anchors{
                            left: parent.left
                            right: automaticFavsCheckBox.left
                            rightMargin: settings.smallMargin
                        }

                        text: "Aggiungi ai preferiti le discussioni a cui rispondo"
                        wrapMode: Text.WordWrap
                    }

                    CheckBox {
                        id: automaticFavsCheckBox

                        anchors {
                            right: parent.right
                            verticalCenter: autoFavsLabel.verticalCenter
                        }

                        checked: settings.addToFavOnReply

                        onCheckedChanged: {
                            settings.addToFavOnReply = checked;
                            AppSettings.setAddFavOnReply(checked);
                        }
                    }
                }
            }
        }
        
        Item {
            id: clearDataSettings

            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
                bottomMargin: settings.smallMargin
            }

            height: clearDataButton.height

            Button {
                id: clearDataButton
                anchors {
                    verticalCenter: parent.verticalCenter
                    right: parent.right
                    rightMargin: settings.mediumMargin
                }

                width: 160
                height: 30

                text: "Elimina dati utente"
                font.pixelSize: settings.fontSizeXS

                onClicked: confirmDialog.open()
            }
        }
    }
    
    QueryDialog {
        id: confirmDialog

        titleText: "Eliminazione dati utente"
        message: "Si vogliono eliminare i dati utente memorizzati dall'applicazione?\n" +
                 "I dati utente comprendono i preferiti salvati, il tema selezionato, " +
                 "il consenso alla privacy, i dati utilizzati per l'invio dei commenti e " +
                 "il tipo di visualizzazione dei video selezionato."
        acceptButtonText: "Sì"
        rejectButtonText: "No"

        onAccepted: {
            window.platformWhite = false;
            settings.fontCorrection = 0;
            settings.addToFavOnReply = false;
            Facebook.resetInMemoryToken();
            Twitter.resetInMemoryToken();
            AppSettings.removeSettings();
            infoBanner.text = "Dati correttamente eliminati"
            infoBanner.iconSource = "qrc:images/ok.png";
            infoBanner.show();
        }
    }

    Loader {
        id: fontSizeDialogLoader

        function show() {
            if(!item)
                sourceComponent = fontSizeDialogComponent;
            item.open();
        }
    }

    Component {
        id: fontSizeDialogComponent

        Item {
            TumblerDialog {
                id: fontSizeDialog

                titleText: "Dimensione carattere:"
                acceptButtonText: "Conferma"
                rejectButtonText: "Annulla"

                columns: [fontSizeColumn]

                TumblerColumn {
                    id: fontSizeColumn

                    items: ListModel {
                        ListElement { value: "-3" }
                        ListElement { value: "-2" }
                        ListElement { value: "-1" }
                        ListElement { value: "Default" }
                        ListElement { value: "+1" }
                        ListElement { value: "+2" }
                        ListElement { value: "+3" }
                        ListElement { value: "+4" }
                        ListElement { value: "+5" }
                        ListElement { value: "+6" }
                        ListElement { value: "+7" }
                        ListElement { value: "+8" }
                        ListElement { value: "+9" }
                        ListElement { value: "+10" }
                    }
                }

                onAccepted: {
                    settings.fontCorrection = fontSizeColumn.selectedIndex - 3;
                    AppSettings.setFontSizeCorrection(settings.fontCorrection);
                }

                onRejected: close()
            }

            function open() {
                fontSizeColumn.selectedIndex = settings.fontCorrection + 3
                fontSizeDialog.open();
            }
        }
    }

    Menu {
        id: exitMenu

        visualParent: pageStack

        MenuLayout {
            MenuItem {
                text: "Esci"
                onClicked: Qt.quit();
            }
        }
    }

    tools: ToolBarLayout {
        id: toolBarLayoutDescription

        ToolIcon {
            iconId: "toolbar-back"

            anchors.left: (parent === undefined ? undefined : parent.left)
            onClicked: {
                if(busyIndicator)
                    busyIndicator.opacity = 0;
                exitMenu.close();
                settingsUiPage.pageStack.pop();
            }
        }

        ToolIcon {
            iconId: "toolbar-view-menu"

            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (exitMenu.status == DialogStatus.Closed) ? exitMenu.open() : exitMenu.close()
        }
    }
}
