﻿import QtQuick 1.1
import com.nokia.meego 1.0

import "script/singlenewsoverviewtab.js" as SingleNewsOverviewTabFn
import "script/settings.js" as AppSettings
import "script/common.js" as CommonScript
import "script/ajax.js" as AjaxScript

Item {
    property variant newsId

    anchors {
        fill: parent
        topMargin: settings.smallMargin
    }

    clip: true;

    Label {
        id: errorTextDetailsView
        width: parent.width - 20
        anchors.centerIn: parent
        opacity: 0
        font.pixelSize: settings.fontSizeL + settings.fontCorrection
        wrapMode: Text.WordWrap
        text: "Impossibile recuperare le informazioni. Assicurati che sia disponibile una connesisone ad Internet.";
        color: settings.errorColor
        onOpacityChanged:
            newsTabBar.opacity = 1 - opacity;
    }

    Loader {
        id: wkWatermarkLoader

        anchors.fill: parent

        function show() {
            if(!item)
                sourceComponent = wkWatermark;

            item.visible = true;
        }
    }

    Component {
        id: wkWatermark

        Image {
            anchors.centerIn: parent

            source: "qrc:images/wk_watermark.png"

            opacity: 0.2

            fillMode: Image.PreserveAspectFit
            smooth: true

            height: Math.min(parent.height, sourceSize.height)
        }
    }

    Flickable {
        id: newsContent

        anchors {
            fill: parent
            leftMargin: settings.smallMargin
            rightMargin: settings.smallMargin
        }

        contentWidth: width
        contentHeight: newsTitle.height + newsInfos.height +
                       newsOverview1.height +
                       downloadHelperLoader.height +
                       (secondPartOverviewLoader.height === 0 ?
                            50 :
                            secondPartOverviewLoader.height + 90)
                            
        flickableDirection: "VerticalFlick"

        Item {
            height: parent.height
            width: parent.width

            Label {
                id: newsTitle

                anchors {
                    top: parent.top
                    left: parent.left
                    right: favouritesStar.left
                }

                font.pixelSize: settings.fontSizeXL + settings.fontCorrection
                horizontalAlignment: "AlignHCenter"
                wrapMode: Text.WordWrap
            }

            Image {
                id: favouritesStar

                anchors {
                    top: parent.top
                    right: parent.right
                    leftMargin: settings.mediumMargin
                }

                opacity: newsTitle.opacity
                visible: newsTitle.text.length > 0

                source: "image://theme/icon-m-toolbar-favorite-" +
                        (isFavourite ? "mark" : "unmark") +
                        (theme.inverted ? "-white" : "");

                MouseArea {
                    anchors.fill: parent

                    onClicked: {
                        isFavourite = !isFavourite;
                        if(!isFavourite)
                            AppSettings.removeFavourite(newsId, isWindowsteca);
                        else
                            AppSettings.setFavourite(newsId, commentsCount, isWindowsteca);
                    }
                }
            }

            Item {
                id: newsInfos
                anchors {
                    top: newsTitle.bottom
                    left: parent.left
                    right: parent.right
                    topMargin: settings.smallMargin
                }

                height: childrenRect.height
                
                Label {
                    id: newsAuthor
                    anchors {
                        top: parent.top
                        left: parent.left
                        right: newsDate.left
                        rightMargin: settings.smallMargin
                    }

                    elide: Text.ElideRight
                    font.pixelSize: settings.fontSizeS + settings.fontCorrection
                    horizontalAlignment: Text.AlignLeft

                    color: window.platformWhite ? settings.nokiotecaBlue : settings.nokiotecaYellow
                }
                
                Label {
                    id: newsDate
                    anchors {
                        top: parent.top
                        right: parent.right
                    }

                    font.pixelSize: settings.fontSizeS + settings.fontCorrection
                    horizontalAlignment: Text.AlignRight

                    color: window.platformWhite ? settings.nokiotecaBlue : settings.nokiotecaYellow
                }
            }

            Text {
                id: newsOverview1

                anchors {
                    top: newsInfos.bottom
                    left: parent.left
                    right: parent.right
                    topMargin: settings.largeMargin
                }
                
                color: window.platformWhite ? settings.darkColor : settings.lightColor
                
                wrapMode: Text.WordWrap

                font.pixelSize: settings.fontSizeL + settings.fontCorrection

                onLinkActivated: {
                    SingleNewsOverviewTabFn.manageLinkOnNews(link);
                }
            }

            Loader {
                id: secondPartOverviewLoader

                anchors {
                    top: newsOverview1.bottom
                    left: parent.left
                    right: parent.right
                    topMargin: settings.largeMargin
                }

                function show() {
                    if(!item)
                        sourceComponent = secondPartOverview
                }

                function setSecondPartOverviewText(text) {
                    show();
                    item.setSecondPartTextOverview(text);
                }
            }
            
            Loader {
                id: downloadHelperLoader

                anchors {
                    bottom: parent.bottom
                    left: parent.left
                    right: parent.right
                }

                function show() {
                    if(!item)
                        sourceComponent = downloadHelper
                }
            }
        }
    }

    ScrollDecorator {
        flickableItem: newsContent
    }
    
    NumberAnimation {
        id: openNewsContent
        target: newsContent
        property: "opacity"
        from: 0
        to: 1
        duration: 250
        easing.type: Easing.Linear
    }

    ListModel {
        id: galleryModel
    }

    Component {
        id: secondPartOverview

        Item {
            height: childrenRect.height

            Component {
                id: imageDelegate
                Item {
                    id: imageContainer
                    property string imageUrl: picUrl
                    
                    width: settings.galleryPreviewPicturesSize
                    height: width
                    scale: PathView.iconScale
                    opacity: PathView.iconOpacity
                    z: PathView.iconScale * 10

                    Image {
                        anchors.horizontalCenter:parent.horizontalCenter

                        sourceSize.width: settings.galleryPreviewPicturesSize
                        smooth: imageContainer.PathView.isCurrentItem

                        fillMode: Image.PreserveAspectFit
                        source: thumbUrl

                        transform: Rotation {
                             origin.x: imageContainer.width / 2
                             origin.y: imageContainer.height / 2
                             axis.x: 0; axis.y: 1; axis.z: 0
                             angle: imageContainer.PathView.angle
                        }

                        MouseArea {
                             anchors.fill: parent
                             enabled: imageContainer.PathView.isCurrentItem

                             onClicked: zoomedImageLoader.showGallery(imageGalleryView);
                        }
                    }
                }
            }

            PathView {
                id: imageGalleryView

                anchors {
                    top: parent.top
                    left: parent.left
                    right: parent.right
                    topMargin: settings.largeMargin
                }

                height: 3 * settings.galleryPreviewPicturesSize / 2

                model: galleryModel
                delegate: imageDelegate
                pathItemCount: count

                path: Path {
                    /*startX: 0
                    startY: 0
                    PathAttribute { name: "z"; value: 0 }
                    PathAttribute { name: "angle"; value: 80 }
                    PathAttribute { name: "iconScale"; value: 0.25 }
                    PathAttribute { name: "iconOpacity"; value: 0.1 }
                    PathLine {
                        x: imageGalleryView.width / 2
                        y: imageGalleryView.height / 2
                    }
                    PathAttribute { name: "z"; value: 100 }
                    PathAttribute { name: "angle"; value: 0 }
                    PathAttribute { name: "iconScale"; value: 1.0 }
                    PathAttribute { name: "iconOpacity"; value: 1.0 }
                    PathLine {
                        x: imageGalleryView.width
                        y: 0
                    }
                    PathAttribute { name: "z"; value: 0 }
                    PathAttribute { name: "angle"; value: -80 }
                    PathAttribute { name: "iconScale"; value: 0.25 }
                    PathAttribute { name: "iconOpacity"; value: 0.1 }*/
                    id: p
                    property real width: imageGalleryView.width
                    property real height: imageGalleryView.height
                    property real cx: width / 2
                    property real cy: height / 2

                    startX: p.cx
                    startY: p.height - settings.galleryPreviewPicturesSize / 2
                    PathAttribute { name: "angle"; value: 0 }
                    PathAttribute { name: "iconScale"; value: 1 }
                    PathAttribute { name: "iconOpacity"; value: 1 }

                    PathQuad {
                        x: p.width
                        y: p.cy - settings.galleryPreviewPicturesSize / 2
                        controlX: 9 * width / 10
                        controlY: imageGalleryView.height - settings.galleryPreviewPicturesSize / 2
                    }
                    PathAttribute { name: "angle"; value: 90 }
                    PathAttribute { name: "iconScale"; value: 0.4 }
                    PathAttribute { name: "iconOpacity"; value: 0.3 }

                    PathQuad {
                        x: p.cx
                        y: settings.galleryPreviewPicturesSize * 0.05
                        controlX: 9 * width / 10
                        controlY: p.height / 8
                    }
                    PathAttribute { name: "angle"; value: 180 }
                    PathAttribute { name: "iconScale"; value: 0.05 }
                    PathAttribute { name: "iconOpacity"; value: 0.1 }

                    PathLine {
                        x: p.cx
                        y: settings.galleryPreviewPicturesSize * 0.05
                    }
                    PathAttribute { name: "angle"; value: -180 }
                    PathAttribute { name: "iconScale"; value: 0.05 }
                    PathAttribute { name: "iconOpacity"; value: 0.1 }

                    PathQuad {
                        x: 0
                        y: p.cy - settings.galleryPreviewPicturesSize / 2
                        controlX: width / 10
                        controlY: p.height / 8
                    }
                    PathAttribute { name: "angle"; value: -90 }
                    PathAttribute { name: "iconScale"; value: 0.4 }
                    PathAttribute { name: "iconOpacity"; value: 0.3 }

                    PathQuad {
                        x: p.cx
                        y: p.height - settings.galleryPreviewPicturesSize / 2
                        controlX: width / 10
                        controlY: imageGalleryView.height - settings.galleryPreviewPicturesSize / 2
                    }
                }
            }

            Label {
                id: tapToZoomLabel

                anchors {
                    top: imageGalleryView.bottom
                    topMargin: settings.smallMargin
                    left: parent.left
                    right: parent.right
                }

                font.pixelSize: settings.fontSizeXS + (settings.fontCorrection / 2)
                horizontalAlignment: Text.AlignHCenter
                text: "Seleziona l'immagine per ingrandire"
            }

            Text {
                id: newsOverview2

                anchors {
                    top: tapToZoomLabel.bottom
                    left: parent.left
                    right: parent.right
                    topMargin: settings.largeMargin
                }

                visible: false
                color: window.platformWhite ? settings.darkColor : settings.lightColor
                wrapMode: Text.WordWrap

                font.pixelSize: settings.fontSizeL + settings.fontCorrection

                onLinkActivated: {
                    SingleNewsOverviewTabFn.manageLinkOnNews(link);
                }
            }

            function getimageGallery() {
                return imageGalleryView;
            }

            function getNewsOverview() {
                return newsOverview2;
            }

            function setSecondPartTextOverview(text) {
                if(text.length > 0) {
                    newsOverview2.text = text;
                    newsOverview2.visible = true;
                }
            }
        }
    }
    
    Component {
        id: downloadHelper

        Item {
            height: childrenRect.height

            Label {
                id: downloadButtonHelper

                anchors {
                    left: parent.left
                    right: parent.right
                }
                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: settings.fontSizeL + settings.fontCorrection

                text: "Per scaricare i file presenti in questo articolo, premi qui"
            }

            Image {
                anchors {
                    top: downloadButtonHelper.bottom
                    horizontalCenter: parent.horizontalCenter
                }

                source: "qrc:images/up_down" + 
                        (window.platformWhite ? "_w" : "") + ".svg"
            }
        }
    }

    ListModel {
        id: videoTypeModel
    }

    Loader {
        id: videoTypeDialogLoader

        anchors.fill: parent

        function show() {
            if(!item)
                sourceComponent = videoTypeDialog;
            item.open();
        }
    }

    Component {
        id: videoTypeDialog

        SelectionDialog {
            titleText: "Mostra video"
            model: videoTypeModel

            onAccepted: {
                switch(selectedIndex) {
                case 0: {
                        SingleNewsOverviewTabFn.makeYoutubeRTSPRequest(model.get(selectedIndex).videoId);
                        break;
                }
                    case 1: {
                        Qt.openUrlExternally("http://youtu.be/" +
                                             model.get(selectedIndex).videoId +
                                             "?hd=1");
                        break;
                    }
                }
            }
        }
    }

    function fetchNews(news_id) {
        var req = AjaxScript.createXMLHttpRequest();

        if(req) {
            var url = (isWindowsteca ?
                           nokioteca.getWindowstecaNewsUrl(news_id) :
                           nokioteca.getNewsUrl(news_id)
                        );
                        
            AjaxScript.loadXMLDoc(req, url, SingleNewsOverviewTabFn.cbFetchNews);
            newsId = news_id;
        }
        //console.debug(url);
    }
}
