import QtQuick 1.1
import com.nokia.meego 1.0

import "script/settings.js" as AppSettings
import "script/facebook.js" as Facebook
import "script/twitter.js" as Twitter

Page {
    id: newsDetailPage

    property variant newsId
    property variant downloadIds
    property string newsTitle
    property string newsThumb
    property int commentsCount: 0
    property bool isWindowsteca: false
    property bool commentsEnabled: true
    property bool isFavourite: AppSettings.isFavourite(newsId, isWindowsteca)

    onDownloadIdsChanged: updateNewsToolBar();

    tools: ToolBar {
        id: newsSharedToolbar

        tools: newsDescriptionToolBar
    }

    ToolBar {
        id: newsTabBar
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
        }

        enabled: (!authDialogLoader.item || !authDialogLoader.item.visible) && isFinite(newsId)

        opacity: 1

        tools: ToolBarLayout {
            anchors.fill: parent
            ButtonRow {
                style: TabButtonStyle { }

                TabButton {
                    id: newsButton
                    text: "Articolo"

                    tab: newsOverview
                    onCheckedChanged: {
                        if(checked) {
                            newsDetailPage.updateNewsToolBar();
                        }
                    }
                }

                TabButton {
                    id: commentsButton
                    text: "Commenti" + (commentsCount > 0 ? " (" + commentsCount + ")" : "")

                    tab: tabComments
                    onCheckedChanged: if(checked) {
                                   if(!commentsLoader.item) {
                                       commentsLoader.source = Qt.resolvedUrl("SingleNewsCommentsTab.qml");
                                       commentsLoader.item.getComments(newsId);
                                   }
                                   newsSharedToolbar.setTools(commentsToolBar);
                               }
                }
            }
        }
    }

    TabGroup {
        id: tabGroup

        anchors {
            top: newsTabBar.bottom
            right: parent.right
            bottom: parent.bottom
            left: parent.left
        }

        enabled: newsTabBar.enabled
        opacity: enabled ? 1 : 0.3

        currentTab: newsOverview

        SingleNewsOverviewTab {
            id: newsOverview
            anchors.fill: parent
        }

        Item {
            id: tabComments

            anchors.fill: parent

            Loader {
                id: commentsLoader
                anchors.fill: parent
            }
        }
    }

    ToolBarLayout {
        id: newsDescriptionToolBar

        visible: false

        ToolIcon {
            iconId: "toolbar-back"
            
            onClicked: {
                if(busyIndicator)
                    busyIndicator.opacity = 0;
                appMenu.close();
                newsDetailPage.pageStack.pop();
            }
        }

        ToolIcon {
            iconId: "toolbar-share"
            
            onClicked: { appMenu.close(); shareDialogLoader.show() }
        }

        ToolIcon {
            iconSource: "qrc:images/internet" + (window.platformWhite ? "_w" : "") + ".svg"
            
            onClicked: { appMenu.close(); Qt.openUrlExternally(nokioteca.getBlogNewsUrl(newsId)) }
        }

        ToolIcon {
            iconId: "toolbar-view-menu"
            
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (appMenu.status == DialogStatus.Closed) ? appMenu.open() : appMenu.close()
        }
    }

    ToolBarLayout {
        id: newsDescriptionToolBarWithDownloads

        visible: false

        ToolIcon {
            iconId: "toolbar-back"
            
            onClicked: {
                if(busyIndicator)
                    busyIndicator.opacity = 0;
                appMenu.close();
                newsDetailPage.pageStack.pop();
            }
        }

        ToolIcon {
            iconId: "toolbar-share"
            
            onClicked: { appMenu.close(); shareDialogLoader.show() }
        }

        ToolIcon {
            iconSource: "qrc:images/store" + (window.platformWhite ? "_w" : "") + ".svg"

            onClicked: { appMenu.close(); selectTheDownload(newsDetailPage.downloadIds) }
        }

        ToolIcon {
            iconSource: "qrc:images/internet" + (window.platformWhite ? "_w" : "") + ".svg"
            
            onClicked: { appMenu.close();  Qt.openUrlExternally(nokioteca.getBlogNewsUrl(newsId)) }
        }

        ToolIcon {
            iconId: "toolbar-view-menu"
            
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (appMenu.status == DialogStatus.Closed) ? appMenu.open() : appMenu.close()
        }
    }

    ToolBarLayout {
        id: commentsToolBar

        visible: false

        ToolIcon {
            iconId: "toolbar-back"
            
            onClicked: {
                if(busyIndicator)
                    busyIndicator.opacity = 0;
                appMenu.close();
                newsDetailPage.pageStack.pop();
            }
        }
        
        ToolIcon {
            id: moveListButton
            iconSource: "qrc:images/up_down" + (window.platformWhite ? "_w" : "") + ".svg"

            opacity: enabled ? 1 : 0.3
            
            onClicked: { appMenu.close(); commentsLoader.item.scrollList(moveListButton) }

            Behavior on rotation {
                NumberAnimation {
                    duration: 100
                }
            }
        }

        ToolIcon {
            iconId: "toolbar-refresh"
            
            onClicked: {
                appMenu.close();
                commentsByTimeButton.checked = false;
                commentsLoader.item.refreshComments();
            }
        }

        ToolButton {
            id: commentsByTimeButton
            iconSource: "qrc:images/time_ordered" + (window.platformWhite ? "_w" : "") + ".svg"
            checkable: true
            anchors.verticalCenter: parent.verticalCenter

            height: 50
            width: 50

            enabled: commentsCount > 2
            opacity: enabled ? 1 : 0.3
            
            onCheckedChanged: { appMenu.close(); commentsLoader.item.sortByTime(checked) }
        }

        ToolIcon {
            iconId: "toolbar-view-menu"
            
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (appMenu.status == DialogStatus.Closed) ? appMenu.open() : appMenu.close()
        }
    }

    Loader {
        id: downloadsDialogLoader

        function show(source) {
            if(!downloadsDialogLoader.item) {
                downloadsDialogLoader.sourceComponent = downloadComponents
            }

            downloadsDialogLoader.item.source = source;
            downloadsDialogLoader.item.open();
        }
    }

    Component {
        id: downloadComponents

        Item {
            property alias source: downloadsModel.source

            XmlListModel {
                id: downloadsModel

                query: "/root/download"

                XmlRole {
                    name: "modelData"
                    query: "title/string()"
                }
                XmlRole {
                    name: "downloadUrl"
                    query: "url/string()"
                }
            }

            SelectionDialog {
                id: downloadsDialog   

                titleText: "Seleziona il download"

                model: downloadsModel

                onAccepted: {
                    Qt.openUrlExternally(downloadsDialog.model.get(downloadsDialog.selectedIndex).downloadUrl);
                }
            }

            function open() {
                downloadsDialog.open()
            }
        }
    }

    Loader {
        id: shareDialogLoader

        anchors.fill: parent

        function show() {
            if(!shareDialogLoader.item)
                shareDialogLoader.sourceComponent = shareDialog;

            shareDialogLoader.item.open();
        }
    }

    Component {
        id: shareDialog

        SelectionDialog {
            titleText: "Condividi"

            model: ListModel {
                ListElement { name: "Su Facebook"; picture: "qrc:images/facebook.png" }
                ListElement { name: "Su Twitter"; picture: "qrc:images/twitter.png" }
                ListElement { name: "Via e-mail"; picture: "qrc:images/email.png" }
            }

            delegate: Item {
                id: delegateItem
                property bool selected: index === selectedIndex;
                height: platformStyle.itemHeight
                anchors.left: parent.left
                anchors.right: parent.right

                MouseArea {
                    id: delegateMouseArea
                    anchors.fill: parent;
                    onPressed: {
                        selectedIndex = index;
                    }
                    onClicked:  accept();
                }

                Rectangle {
                    id: backgroundRect
                    anchors.fill: parent
                    color: delegateItem.selected ? platformStyle.itemSelectedBackgroundColor : platformStyle.itemBackgroundColor
                }

                BorderImage {
                    id: background

                    anchors.fill: parent
                    border { left: 22; top: 22; right: 22; bottom: 22 }
                    source: delegateMouseArea.pressed ? platformStyle.itemPressedBackground :
                            delegateItem.selected ? platformStyle.itemSelectedBackground :
                            platformStyle.itemBackground
                }

                Item {
                    anchors {
                        verticalCenter: delegateItem.verticalCenter
                        left: parent.left
                        right: parent.right
                        leftMargin: platformStyle.itemLeftMargin
                        rightMargin: platformStyle.itemRightMargin
                    }

                    Image {
                        id: itemImage
                        anchors {
                            verticalCenter: parent.verticalCenter
                            left: parent.left
                        }

                        source: picture
                        sourceSize.width: platformStyle.graphicSizeSmall
                        sourceSize.height: platformStyle.graphicSizeSmall
                    }

                    Text {
                        anchors {
                            verticalCenter: parent.verticalCenter
                            left: itemImage.right
                            leftMargin: platformStyle.leftMargin
                        }
                        elide: Text.ElideRight
                        color: delegateItem.selected ? platformStyle.itemSelectedTextColor : platformStyle.itemTextColor
                        text: name
                        font: platformStyle.itemFont
                    }
                }
            }

            onAccepted: {
                var accessToken;
                if(busyIndicator)
                    busyIndicator.opacity = 1;
                switch(selectedIndex) {
                    case 0: {
                        if(!Facebook.shareNewsOnFacebook(newsId, newsTitle, newsThumb, isWindowsteca)) {
                            var authDiag = getAuthenticationDialog("Facebook");
                            authDiag.visible = true;
                            authDiag.loadFacebookLoginPage();
                        }
                        break;
                    }
                    case 1: {
                        if(!Twitter.shareNewsOnTwitter(newsId, newsTitle, isWindowsteca)) {
                            Twitter.getHttpTwitterToken();
                        }
                        break;
                    }
                    case 2: {
                        Qt.openUrlExternally("mailto:?subject=" +
                                             nokioteca.getShareMailSubject() +
                                             "&body=" + nokioteca.getShareText(newsId, true, isWindowsteca));
                        if(busyIndicator)
                            busyIndicator.opacity = 0;
                        break;
                    }
                }
            }
        }
    }

    Loader {
        id: authDialogLoader
        anchors.fill: parent
    }

    Component {
        id: authenticationDialogComponent

        AuthenticationDialog {
            id: authenticationDialog

            visible: false
            onFinished: {
                if(state == "Facebook") {
                    if(url.startsWith(nokioteca.getSocialCallbackUrl())) {
                        var auth_url = url;
                        authenticationDialog.visible = false;
                        Facebook.getFacebookAccessToken(auth_url);
                    }
                }
                else { //Twitter
                    if(url.length === 0) {
                        return;
                    }

                    if(url.startsWith(nokioteca.getSocialCallbackUrl())) {
                        if(authenticationDialog.visible === true) {
                            var auth_ver_url = url;
                            authenticationDialog.visible = false;
                            Twitter.obtainAccessToken(auth_ver_url);
                        }
                    } else {
                        authenticationDialog.visible = true;
                    }
                }
            }

            onLoadFailed: {
                if(state == "Facebook") {
                    authenticationDialog.visible = false;
                    infoBanner.text = "Accesso non riuscito";
                    infoBanner.iconSource = "qrc:images/facebook.png";
                    infoBanner.show();
                }
                else {
                    authenticationDialog.visible = false;
                    infoBanner.text = "Accesso non riuscito";
                    infoBanner.iconSource = "qrc:images/twitter.png";
                    infoBanner.show();
                }
            }
        }
    }

    function updateNewsToolBar() {
        if(!newsButton.checked)
            return;
        if(newsDetailPage.downloadIds && newsDetailPage.downloadIds.length > 0) {
            newsSharedToolbar.setTools(newsDescriptionToolBarWithDownloads);
            newsDescriptionToolBarWithDownloads.visible = true;
        }
        else {
            newsSharedToolbar.setTools(newsDescriptionToolBar);
            newsDescriptionToolBar.visible = true;
        }
    }

    function refreshCommentsCount(prevCount, newCount) {
        if(prevCount > 0)
            commentsCount = commentsCount + (newCount - prevCount);
        else
            commentsCount = Math.max(commentsCount, newCount);

        if(isFavourite)
            AppSettings.setFavourite(newsId, commentsCount);
    }

    function fetchDetails(newsId) {
        newsDetailPage.newsId = newsId;
        newsOverview.fetchNews(newsId);
    }

    function selectTheDownload(downloadList) {
        if(downloadList.length === 1)
            Qt.openUrlExternally(nokioteca.getDownloadUrl(downloadList[0]));
        else {
            downloadsDialogLoader.show(nokioteca.getMultiDownloadsUrl(downloadList));
        }
    }

    function getAuthenticationDialog(state) {
        if(!authDialogLoader.item) {
            authDialogLoader.sourceComponent = authenticationDialogComponent;
        }
        authDialogLoader.item.state = state;

        return authDialogLoader.item;
    }
}
