.pragma library

var nkFavs = null;
var wkFavs = null;

// First, let's create a short helper function to get the database connection
function getDatabase() {
    return openDatabaseSync("NokiotecaApp", "1.0", "Nokioteca App Settings", 100000);
}

// At the start of the application, we can initialize the tables we need if they haven't been created yet
function initialize() {
    var db = getDatabase();
    db.transaction(
                function(tx) {
                    // Create the settings table if it doesn't already exist
                    // If the table exists, this is skipped
                    tx.executeSql('CREATE TABLE IF NOT EXISTS settings(setting TEXT UNIQUE, value TEXT)');

                    tx.executeSql('CREATE TABLE IF NOT EXISTS favourites(newsId INTEGER UNIQUE, comments NUMBER)');
                    
                    tx.executeSql('CREATE TABLE IF NOT EXISTS wkFavourites(newsId INTEGER UNIQUE, comments NUMBER)');
                }
    );
}

function removeSettings() {
    var db = getDatabase();
    
    db.transaction(
                function(tx) {
                    tx.executeSql('DELETE FROM settings');
                    tx.executeSql('DELETE FROM favourites');
                    tx.executeSql('DELETE FROM wkFavourites');
                }
    );
}

function useWhiteTheme() {
    var res = getSetting("useWhiteTheme");
    if(res === "na") res = false;
    return res;
}

function getFontSizeCorrection() {
    var res = getSetting("fontSizeCorrection");
    if(res === "na") res = 0;
    return res;
}

function getSelectedVideoType() {
    var res = getSetting("videoType");
    if(res === "na") res = 3;
    return parseInt(res);
}

function addFavOnReply() {
    var res = getSetting("addFavOnReply");
    if(res === "na") res = false;
    return res;
}

function getPrivacyAgreement() {
    var res = getSetting("privacyAgreement");
    if(res === "na") res = false;
    return res;
}

function getLastUsedName() {
    var res = getSetting("lastUsedName");
    if(res === "na") res = "";
    return res;
}

function getLastUsedMail() {
    var res = getSetting("lastUsedMail");
    if(res === "na") res = "";
    return res;
}

function getLastUsedSite() {
    var res = getSetting("lastUsedSite");
    if(res === "na") res = "";
    return res;
}

function getServerSettingCheckingTime() {
    var res = getSetting("serverSettingsCheckingTime");
    if(res === "na") res = 0;
    return res;
}

function getCommentsUniversalEnabled() {
    var res = getSetting("commentsEnabled");
    if(res === "na") res = true;
    return res;
}

function getSearchUniversalEnabled() {
    var res = getSetting("searchEnabled");
    if(res === "na") res = true;
    return res;
}

function getRecommendNewsUrl() {
    var res = getSetting("recommendNewsUrl");
    if(res === "na") res = "";
    return res;
}

function getFacebookToken() {
    var res = getSetting("facebookToken");
    if(res === "na") res = "";
    return res;
}

function getTwitterToken() {
    var res = getSetting("twitterToken");
    if(res === "na") res = "";
    return res;
}

function getTwitterTokenSecret() {
    var res = getSetting("twitterTokenSecret");
    if(res === "na") res = "";
    return res;
}

function setTheme(isWhite) {
    return setSetting("useWhiteTheme", isWhite);
}

function setFontSizeCorrection(sizeCorrection) {
    return setSetting("fontSizeCorrection", sizeCorrection);
}

function setSelectedVideoType(type) {
    return setSetting("videoType", type);
}

function setAddFavOnReply(isAutomatic) {
    return setSetting("addFavOnReply", isAutomatic);
}

function setPrivacyAgreement(agree) {
    return setSetting("privacyAgreement", agree);
}

function setLastUsedName(name) {
    return setSetting("lastUsedName", name);
}

function setLastUsedMail(mail) {
    return setSetting("lastUsedMail", mail);
}

function setLastUsedSite(site) {
    return setSetting("lastUsedSite", site);
}

function setServerSettingCheckingTime(checkTime) {
    return setSetting("serverSettingsCheckingTime", checkTime);
}

function setCommentsUniversalEnabled(cue) {
    return setSetting("commentsEnabled", cue);
}

function setSearchUniversalEnabled(sue) {
    return setSetting("searchEnabled", sue);
}

function setRecommendNewsUrl(rnu) {
    return setSetting("recommendNewsUrl", rnu);
}

function setFacebookToken(token) {
    return setSetting("facebookToken", token);
}

function setTwitterToken(token) {
    return setSetting("twitterToken", token);
}

function setTwitterTokenSecret(tokenSecret) {
    return setSetting("twitterTokenSecret", tokenSecret);
}

function getPrevFavComments(newsId, fromWindowsteca) {
    return (fromWindowsteca ? getPrevWindowstecaFavComments(newsId) : getPrevNokiotecaFavComments(newsId));
}

function getFavouritesIds(ofWindowsteca) {
    return (ofWindowsteca ? getWindowstecaFavouritesIds() : getNokiotecaFavouritesIds());
}

function isFavourite(newsId, onWindowsteca) {
    return (onWindowsteca ? isWindowstecaFavourite(newsId) : isNokiotecaFavourite(newsId));
}

function setFavourite(newsId, comments, onWindowsteca) {
    return (onWindowsteca ? setWindowstecaFavourite(newsId, comments) : setNokiotecaFavourite(newsId, comments));
}

function removeFavourite(newsId, fromWindowsteca) {
    return (fromWindowsteca ? removeWindowstecaFavourite(newsId) : removeNokiotecaFavourite(newsId));
}

function removeFavourites(fromWindowsteca) {
    return (fromWindowsteca ? removeWindowstecaFavourites() : removeNokiotecaFavourites());
}


//Gestione globale preferenze

// This function is used to write a setting into the database
function setSetting(setting, value) {
    // setting: string representing the setting name (eg: "username")
    // value: string representing the value of the setting (eg: "myUsername")
    var db = getDatabase();
    var res = "";
    db.transaction(function(tx) {
                       var rs = tx.executeSql('INSERT OR REPLACE INTO settings VALUES (?,?);', [setting, value]);
                       if (rs.rowsAffected > 0) {
                           res = true;
                       } else {
                           res = false;
                       }
                   }
    );
    // The function returns true if it was successful, or false if it wasn't
    return res;
}

// This function is used to retrieve a setting from the database
function getSetting(setting) {
    var db = getDatabase();
    var res = "";
    db.transaction(function(tx) {
                       var rs = tx.executeSql('SELECT value FROM settings WHERE setting = ?;', [setting]);
                       if(rs.rows.length > 0) {
                           res = rs.rows.item(0).value;
                       } else {
                           res = "na";
                       }
                   }
    );
    // The function returns "na" if the setting was not found in the database
    // For more advanced projects, this should probably be handled through error codes
    return res;
}




// Gestione preferiti
function setNokiotecaFavourite(newsId, comments) {
    // newsId: id of the news to make a favourite
    // comments: number of comments currently at the news
    var db = getDatabase();
    var res = "";

    db.transaction(function(tx) {
                var rs = tx.executeSql('INSERT OR REPLACE INTO favourites VALUES (?,?);', [newsId, comments]);
                if (rs.rowsAffected > 0) {
                    res = true;
                    if(!nkFavs)
                        nkFavs = new Object();
                    nkFavs[newsId] = comments;
                } else {
                    res = false;
                }
            }
    );

    // The function returns true if it was successful, or false if it wasn't
    return res;
}

function setWindowstecaFavourite(newsId, comments) {
    // newsId: id of the news to make a favourite
    // comments: number of comments currently at the news
    var db = getDatabase();
    var res = "";

    db.transaction(function(tx) {
                var rs = tx.executeSql('INSERT OR REPLACE INTO wkFavourites VALUES (?,?);', [newsId, comments]);
                if (rs.rowsAffected > 0) {
                    res = true;
                    if(!wkFavs)
                        wkFavs = new Object();
                    wkFavs[newsId] = comments;
                } else {
                    res = false;
                }
            }
    );

    // The function returns true if it was successful, or false if it wasn't
    return res;
}

function removeNokiotecaFavourite(newsId) {
    // newsId: id of the news to make a favourite
    var db = getDatabase();
    var res = "";
    db.transaction(function(tx) {
                       var rs = tx.executeSql('DELETE FROM favourites WHERE newsId = ?;', [newsId]);
                       if (rs.rowsAffected > 0) {
                           res = true;
                       } else {
                           res = false;
                       }
                   }
    );
    
    getNokiotetaFavourites();

    // The function returns true if it was successful, or false if it wasn't
    return res;
}

function removeWindowstecaFavourite(newsId) {
    // newsId: id of the news to make a favourite
    var db = getDatabase();
    var res = "";
    db.transaction(function(tx) {
                       var rs = tx.executeSql('DELETE FROM wkFavourites WHERE newsId = ?;', [newsId]);
                       if (rs.rowsAffected > 0) {
                           res = true;
                       } else {
                           res = false;
                       }
                   }
    );

    getWindowstecaFavourites();

    // The function returns true if it was successful, or false if it wasn't
    return res;
}

function isNokiotecaFavourite(newsId) {
    if(!nkFavs)
        getNokiotecaFavourites();

    if(nkFavs[newsId])
        return true;

    return false;
}

function isWindowstecaFavourite(newsId) {
    if(!wkFavs)
        getWindowstecaFavourites();

    if(wkFavs[newsId])
        return true;

    return false;
}

function getPrevNokiotecaFavComments(newsId) {
    if(!nkFavs)
        getNokiotecaFavourites();

    return nkFavs[newsId];
}

function getPrevWindowstecaFavComments(newsId) {
    if(!wkFavs)
        getWindowstecaFavourites();

    return wkFavs[newsId];
}

function getNokiotecaFavouritesIds() {
    var nkFavsIds = "";

    for(var nkFav in nkFavs) {
        if(nkFavs.hasOwnProperty(nkFav) && nkFav !== "length") {
            nkFavsIds += (nkFav + ",");
        }
    }
    return nkFavsIds;
}

function getWindowstecaFavouritesIds() {
    var wkFavsIds = "";

    for(var wkFav in wkFavs) {
        if(wkFavs.hasOwnProperty(wkFav) && wkFav !== "length") {
            wkFavsIds += (wkFav + ",");
        }
    }
    return wkFavsIds;
}

function getNokiotecaFavourites() {
    var db = getDatabase();
    nkFavs = new Object();
    nkFavs.length = 0;
    db.transaction(function(tx) {
                       var rs = tx.executeSql('SELECT * FROM favourites ORDER BY newsId;');
                       for(var i = 0; i < rs.rows.length; i++) {
                           nkFavs[rs.rows.item(i).newsId] = rs.rows.item(i).comments;
                           nkFavs.length++;
                       }

                   }
    );
    return nkFavs;
}

function getWindowstecaFavourites() {
    var db = getDatabase();
    wkFavs = new Object();
    wkFavs.length = 0;
    db.transaction(function(tx) {
                       var rs = tx.executeSql('SELECT * FROM wkFavourites ORDER BY newsId;');
                       for(var i = 0; i < rs.rows.length; i++) {
                           wkFavs[rs.rows.item(i).newsId] = rs.rows.item(i).comments;
                           wkFavs.length++;
                       }

                   }
    );
    return wkFavs;
}

function removeNokiotecaFavourites() {
    var db = getDatabase();

    db.transaction(
                function(tx) {
                    tx.executeSql('DELETE FROM favourites');
                }
    );

    nkFavs = new Object();
}

function removeWindowstecaFavourites() {
    var db = getDatabase();

    db.transaction(
                function(tx) {
                    tx.executeSql('DELETE FROM wkFavourites');
                }
    );

    wkFavs = new Object();
}
