Qt.include("xauth.js")
Qt.include("settings.js")

var OAUTH_REQUEST_TOKEN_URL = "https://api.twitter.com/oauth/request_token";
var OAUTH_ACCESS_TOKEN_URL = "https://api.twitter.com/oauth/access_token";

// Actions
var STATUS_UPDATE_URL = "https://api.twitter.com/1.1/statuses/update.json";

var xauth = new XAuth();
var hasToken = false;

var newsToShare = "";
var newsToShareTitle = "";
var newsFromWindowsteca = false;

function resetInMemoryToken() {
    hasToken = false;
    xauth.setTokenAndSecret("", "");
}

function shareNewsOnTwitter(newsId, newsTitle, isWindowsteca) {
    newsToShare = newsId;
    newsToShareTitle = newsTitle;
    newsFromWindowsteca = isWindowsteca;
    var token = getTwitterToken();
    xauth.setErrorCallback(manageTwitterErrors);
    var tokenSecret = getTwitterTokenSecret();
    if(token.length === 0 || tokenSecret.length === 0) {
        hasToken = false;
        xauth.setTokenAndSecret("", "");
        return false;
    }

    hasToken = true;
    xauth.setTokenAndSecret(token, tokenSecret);
    shareLinkOnTwitter();
    return true;
}

function getHttpTwitterToken() {
    xauth.setTokenAndSecret("", "");

    var pars = [xauth.OAuthCallbackKey(), nokioteca.getSocialCallbackUrl()];
    xauth.webRequest(true, OAUTH_REQUEST_TOKEN_URL, [pars], parseRequestToken);
}

function parseRequestToken(response) {
    var oauth_token = parseParameter(response, "oauth_token");
    var oauth_token_secret = parseParameter(response, "oauth_token_secret");

    xauth.setTokenAndSecret(oauth_token, oauth_token_secret);
    hasToken = false;

    var authDialog = newsDetailPage.getAuthenticationDialog("Twitter");
    authDialog.visible = true;
    authDialog.loadTwitterLoginPage(oauth_token);
}

function obtainAccessToken(url) {
    var oauth_verifier = parseParameter(url, "oauth_verifier");

    var pars = [xauth.OAuthVerifierKey(), oauth_verifier];

    xauth.webRequest(true, OAUTH_ACCESS_TOKEN_URL, [pars], function(token) { //  this.parseTokenSync);
         var oauthToken = parseParameter(token, "oauth_token");
         var oauthTokenSecret = parseParameter(token, "oauth_token_secret");
         var user_id = parseParameter(token, "user_id");
         var screen_name = parseParameter(token, "screen_name");
         if(typeof(oauthToken) == "undefined" || oauthToken.length == 0) {
             manageTwitterErrors(0, "");
             return;
         }
         hasToken = true;
         setTwitterToken(oauthToken);
         setTwitterTokenSecret(oauthTokenSecret);

         xauth.setTokenAndSecret(oauthToken, oauthTokenSecret);
         shareLinkOnTwitter();
     });
}


/* Update status */
function shareLinkOnTwitter() {
    var status = " " + (newsFromWindowsteca ?
                            nokioteca.getWindowstecaBlogNewsUrl(newsToShare) :
                            nokioteca.getBlogNewsUrl(newsToShare)
                        );
                        
    var tweetLen = (newsToShareTitle + status).length;
    if(tweetLen > 140) {
        newsToShareTitle = newsToShareTitle.substring(0, 140 - status.length - 3);
        status = newsToShareTitle + "..." + status;
    }
    else {
        status = newsToShareTitle + status;
    }

    var url = STATUS_UPDATE_URL + "?status=" + status;
    var params = new Array();

    params.push(["status", status]);

    if(busyIndicator)
        busyIndicator.opacity = 0;

    xauth.webRequest(true, STATUS_UPDATE_URL, params, parseShareLink);
}

function parseShareLink(responseText) {
    if(responseText) {
        infoBanner.text = "Articolo condiviso correttamente"
        infoBanner.iconSource = "qrc:images/twitter.png"
        infoBanner.show();
        return;
    }
}

/* Parse parameter from given URL */
function parseParameter(url, parameter) {
    var parameterIndex = url.indexOf(parameter);
    if(parameterIndex<0) {
        // We didn't find parameter
        return "";
    }
    var equalIndex = url.indexOf("=", parameterIndex);
    if(equalIndex<0) {
        return "";
    }
    var value = "";
    var nextIndex = url.indexOf("&", equalIndex+1);
    if(nextIndex<0) {
        value = url.substring(equalIndex+1);
    } else {
        value = url.substring(equalIndex+1, nextIndex);
    }
    return value;
}

function manageTwitterErrors(status, errorUrl) {
    if(status === 401) {
        hasToken = false;
        xauth.setTokenAndSecret("", "");
        setTwitterToken("");
        setTwitterTokenSecret("");

        infoBanner.text = "Autorizzazione non concessa"
        infoBanner.iconSource = "qrc:images/twitter.png"
        infoBanner.show();
        
        return;
    }

    if(busyIndicator)
        busyIndicator.opacity = 0;

    infoBanner.text = "Si è verificato un errore."
    infoBanner.iconSource = "qrc:images/twitter.png"
    infoBanner.show();
}
